/********************************************************************
* $ Source $
*
* Workfile: drv_pio.c
* Author: MICROCHIPS Korea CAE Team
* Date  : 2016/08
*
* [Test Environment]
* - Development Environment : MPLAB X IDE v3.35
* - Compiler                : XC8 v1.38
* - Hardware                : PICDEM 2 Plus Demo Board
* - Target Processor        : PIC16F1937
*
* Description :
*  PIO driver.
*
* Revision History:
********************************************************************/


/********************************************************************
* Header Files
********************************************************************/

#include <xc.h>
#include "pic16f1937.h"
#include "drv_pio.h"



/********************************************************************
* Function		: DRV_PIOB_Init
* Description	: PortB Initialization
* Argument		: None
* Return		: None
********************************************************************/

void DRV_PIOB_Init(void)
{
	/*-------------------------------------------------------------*/
	/* ANSELB : Analog Selection Port B (ANSELB) register          */
	/* Description :                                               */
	/* Bit-field Value 0 : digital port                            */
	/*                 1 : analog input port                       */
	/* [Property]                                                  */
	/*     Mandatory register to select Digital orAnalog set       */
	/*-------------------------------------------------------------*/
	ANSELB = 0x00;		// All pins are digital pins

	/*-------------------------------------------------------------*/
	/* LATB : Port B Data (Output) Latch register                  */
	/* Description :                                               */
	/* Writing operation to the LATB register has the same effect  */
	/* as a write to the corresponding PORTx register.             */
	/* [Property]                                                  */
	/*     Mandatory register to select LOW or HIGH                */
	/*-------------------------------------------------------------*/
	LATB = 0x00;		// See upper comments

	/*-------------------------------------------------------------*/
	/* PORTB : PORT B register                                     */
	/* Description :                                               */
	/* Bit-field Value 0 : Output level is LOW.                    */
	/*                 1 : Output level is HIGH.                   */
	/* [Property]                                                  */
	/*     Optional register to select LOW or HIGH                 */
	/*-------------------------------------------------------------*/
	PORTB = 0x00;		// All pins are LOW

	/*-------------------------------------------------------------*/
	/* TRISB : PortB Tri-state register                            */
	/* Description :                                               */
	/* Bit-field Value 0 : Direction is OUTPUT.                    */
	/*                 1 : Direction is INPUT.                     */
	/* [Property]                                                  */
	/*     Mandatory register to select INPUT or OUTPUT            */
	/*-------------------------------------------------------------*/
	TRISB = 0x00;		// All pins are output
}



/********************************************************************
* Function		: DRV_PIOB_IOC_Init
* Description	: PortB Interrupt-On-Change(IOC) Initialization
* Argument		: None
* Return		: None
********************************************************************/

void DRV_PIOB_IOC_Init(void)
{
	/*-------------------------------------------------------------*/
	/* IOCBP : INTERRUPT-ON-CHANGE Positive register               */
	/* Description :                                               */
	/* Bit-field Value 0 : Interrupt-on-Change disabled            */
	/*                 1 : Interrupt-on-Change enabled on the pin. */
	/* [Property]                                                  */
	/*     Mandatory register to select enable or disable          */
	/*-------------------------------------------------------------*/
	IOCBPbits.IOCBP0 = 1;

	/*-------------------------------------------------------------*/
	/* IOCBP : INTERRUPT-ON-CHANGE Negative register               */
	/* Description :                                               */
	/* Bit-field Value 0 : Interrupt-on-Change disabled            */
	/*                 1 : Interrupt-on-Change enabled on the pin. */
	/* [Property]                                                  */
	/*     Mandatory register to select enable or disable          */
	/*-------------------------------------------------------------*/
	IOCBNbits.IOCBN0 = 1;

	/*-------------------------------------------------------------*/
	/* IOCBP : INTERRUPT-ON-CHANGE Flag register                   */
	/* Description :                                               */
	/* Bit-field Value 0 : No change was detected                  */
	/*                 1 : Change was detected in the pin.         */
	/* [Property]                                                  */
	/*     Mandatory register to select enable or disable          */
	/*-------------------------------------------------------------*/
	IOCBFbits.IOCBF0 = 0;	/* Clear by default. */

	/*-------------------------------------------------------------*/
	/* INTCON : Interrupt Control register                         */
	/* Description :                                               */
	/* bit [7] GIE    : Global Interrupt Enable bit                */
	/* bit [6] PEIE   : Peripheral Interrupt Enable bit            */
	/* bit [5] TMR0IE : Timer0 Overflow Interrupt Enable bit       */
	/* bit [4] INTE   : INT External Interrupt Enable bit          */
	/* bit [3] IOCIE  : Interrupt-on-Change Enable bit             */
	/* bit [2] TMR0IF : Timer0 Overflow Interrupt Flag bit         */
	/* bit [1] INTF   : INT External Interrupt Flag bit            */
	/* bit [0] IOCIF  : Interrupt-on-Change Interrupt Flag bit     */
	/*                                                             */
	/* Bit-field Value 0 : No change was detected                  */
	/*                 1 : Change was detected in the pin.         */
	/* [Property]                                                  */
	/*     Mandatory register to activate associated interrupt.    */
	/*-------------------------------------------------------------*/
	INTCONbits.IOCIF = 0;	/* Clear by default */
	INTCONbits.IOCIE = 1;	/* Enable IOC */
}



/********************************************************************
* Function		: DRV_PIOC_Init
* Description	: PortC Initialization
* Argument		: None
* Return		: None
********************************************************************/

void DRV_PIOC_Init(void)
{
	LATC = 0x00;

	/* Pin 6 in PortC is OUTPUT. */
	TRISCbits.TRISC6 = 0x0;
	PORTCbits.RC6 = 0x00;

	/* Pin 7 in PortC is INPUT. */
	TRISCbits.TRISC7 = 0x1;
	PORTCbits.RC7 = 0x00;
}

/* End of File */
