/********************************************************************
* $ Source $
*
* Workfile: drv_timer.c
* Author: MICROCHIPS Korea CAE Team
* Date  : 2016/08
*
* [Test Environment]
* - Development Environment : MPLAB X IDE v3.35
* - Compiler                : XC8 v1.38
* - Hardware                : PICDEM 2 Plus Demo Board
* - Target Processor        : PIC16F1937
*
* Description :
*  Timer 0/1/2/4 driver.
*
* Revision History:
********************************************************************/


/********************************************************************
*	Header Files
********************************************************************/

#include <xc.h>
#include "pic16f1937.h"
#include "drv_timer.h"



/********************************************************************
* Function		: DRV_Timer0_Init
* Description	: 8bits Timer 0 Initialization
* Argument		: INT_flag - Select interrupt enable or disable
* Return		: None
********************************************************************/

void DRV_Timer0_Init(uint8_t INT_flag)
{
	/*-------------------------------------------------------------------*/
	/* OPTION_REG : OPTION Register                                      */
	/* Description :                                                     */
	/* bit [7]   WPUEN  : Weak Pull-up Enable bit                        */
	/* bit [6]   INTEDG : Interrupt Edge Select bit                      */
	/* bit [5]   TMR0CS : Timer0 Clock Source Select bit                 */
	/* bit [4]   TMR0SE : Timer0 Source Edge Select bit                  */
	/* bit [3]   PSA    : Prescaler Assignment bit                       */
	/* bit [2-0] PS     : Prescaler Rate Select bits                     */
	/* [Property]                                                        */
	/*     Mandatory register to operate Timer0                          */
	/*-------------------------------------------------------------------*/
	/* Store default register value. */
	OPTION_REG = (OPTION_REG & 0xC0) | 0xC7 & 0x3F; 

	OPTION_REGbits.nWPUEN = 1;		// All weak pull-ups are disabled
	OPTION_REGbits.INTEDG = 1;		// Interrupt on rising edge of INT pin
	OPTION_REGbits.TMR0CS = 0;		// Internal instruction cycle clock (FOSC/4)
	OPTION_REGbits.TMR0SE = 0;		// Increment on low-to-high transition on T0CKI pin
	OPTION_REGbits.PSA = 0;			// Prescaler is assigned to the Timer0 module
	OPTION_REGbits.PS = 7;			// Prescaling rate is 1:256

	/* Clear Timer0 value. */
	TMR0 = 0xFF;

	/* Clear Interrupt flag before enabling the interrupt. */
	INTCONbits.TMR0IF = 0;

	/* Determine Timer0 interrupt activation. */
	INTCONbits.TMR0IE = INT_flag;
}



/********************************************************************
* Function		: DRV_Timer1_Init
* Description	: 16bits Timer1 Initialization
* Argument		: None
* Return		: None
********************************************************************/

void DRV_Timer1_Init(uint8_t INT_flag)
{
	/*-------------------------------------------------------------------*/
	/* T1CON : Timer1 Control Register                                   */
	/* Description :                                                     */
	/* bit[7-6] TMR1CS  : Timer1 Clock Source Select bits                */
	/* bit[5-4] T1CKPS  : Timer1 Input Clock Prescale Select bits        */
	/* bit[3]   T1OSCEN : LP Oscillator Enable Control bit               */
	/* bit[2]   T1SYNC  : Timer1 External Clock Input Synchronization Control bit */
	/* bit[1]           : Not Used                                       */
	/* bit[0]   TMR1ON  : Timer1 On bit                                  */
	/* [Property]                                                        */
	/*     Mandatory register to operate Timer1                          */
	/*-------------------------------------------------------------------*/
	/* Set TMR1 to make real-time clock. */
	T1CONbits.TMR1CS = 2;		// Timer1 clock source is pin or oscillator 32.768Hz
	T1CONbits.T1CKPS = 0;		// 1:1 prescale value
	T1CONbits.T1OSCEN = 1;		// Dedicated Timer1 oscillator circuit enabled
	T1CONbits.nT1SYNC = 0;		// Synchronize external clock input with system clock (FOSC)
	T1CONbits.TMR1ON = 1;		// Enables Timer1

	/* Initialize TMR1H and TMR1L */
	/* From 0x8000 to 0xFFFF means number of ticks 32768 occurs. */
	TMR1H = 0x80;
	TMR1L = 0x0;

	/*-------------------------------------------------------------------*/
	/* When Timer1 gate is needless, do not initialize gate-related      */
	/* bit fields such as PEIE, TMR1GE, T1GPOL and T1GTM in the INTCON.  */
	/*-------------------------------------------------------------------*/
	//INTCONbits.PEIE = 1;
	//T1GCONbits.TMR1GE = 1;
	//T1GCONbits.T1GPOL = 1;
	//T1GCONbits.T1GTM = 1;

	/* Clear Interrupt flag before enabling the interrupt. */
	PIR1bits.TMR1IF = 0;

	/* Determine Timer1 interrupt activation. */
	PIE1bits.TMR1IE = INT_flag;
}



/********************************************************************
* Function		: DRV_Timer2_Init
* Description	: 8bits Timer2 Initialization
* Argument		: None
* Return		: None
********************************************************************/

void DRV_Timer2_Init(uint8_t INT_flag)
{
	/*-------------------------------------------------------------------*/
	/* T2CON : Timer2 Control Register                                   */
	/* Description :                                                     */
	/* bit[7]          : Not Used                                        */
	/* bit[6-3] TOUTPS : Timer Output Postscaler Select bits             */
	/* bit[2]   TMR2ON : Timer2 On bit                                   */
	/* bit[1-0] T2CKPS : Timer2 Clock Prescale Select bits               */
	/* [Property]                                                        */
	/*     Mandatory register to operate Timer2                          */
	/*-------------------------------------------------------------------*/
	T2CONbits.T2OUTPS = 15;		// Select Postscaler 1:16 
	T2CONbits.TMR2ON = 1;		// Timer2 is ON
	T2CONbits.T2CKPS = 2;		// Prescaler is 16

	/* Set Timer2 Module Period Register to 255. */
	PR2 = 255;

	/* Clear Timer2 module register. */
	TMR2 = 0;

	/* Clear Interrupt flag before enabling the interrupt. */
	PIR1bits.TMR2IF = 0;

	/* Determine Timer2 interrupt activation. */
	PIE1bits.TMR2IE = INT_flag;
}



/********************************************************************
* Function		: DRV_Timer4_Init
* Description	: 8bits Timer4 Initialization
* Argument		: None
* Return		: None
********************************************************************/

void DRV_Timer4_Init(uint8_t INT_flag)
{
	/*-------------------------------------------------------------------*/
	/* T4CON : Timer4 Control Register                                   */
	/* Description :                                                     */
	/* bit[7]          : Not Used                                        */
	/* bit[6-3] TOUTPS : Timer Output Postscaler Select bits             */
	/* bit[2]   TMR4ON : Timer4 On bit                                   */
	/* bit[1-0] T4CKPS : Timer4 Clock Prescale Select bits               */
	/* [Property]                                                        */
	/*     Mandatory register to operate Timer4                          */
	/*-------------------------------------------------------------------*/
    T4CONbits.T4OUTPS = 15;      // Select 1:16
	T4CONbits.TMR4ON = 1;       // Start Timer4
    T4CONbits.T4CKPS = 3;       // Prescaler is 1:64

	/* Set Timer4 Module Period Register to 1. */
    PR4 = 1;

	/* Clear Timer4 module register. */
	TMR4 = 0;

	/* Clear Interrupt flag before enabling the interrupt. */
	PIR3bits.TMR4IF = 0;

	/* Determine Timer2 interrupt activation. */
	PIE3bits.TMR4IE = INT_flag;
}

/* End of File */
