/********************************************************************
* $ Source $
*
* Workfile: main.c
* Author: MICROCHIPS Korea CAE Team
* Date  : 2016/08
* Revision History:
*
* [Test Environment]
* - Development Environment : MPLAB X IDE v3.35
* - Compiler                : XC8 v1.38
* - Hardware                : PICDEM 2 Plus Demo Board
* - Target Processor        : PIC16F1937
* - Debugging Tool          : MPLAB ICD 3
*   Note : We can change a debugging tool in the "project property".
*
* Description :
*  This is main application code to toggle RB0, RB1, RB2 and RB3 in PIOB
*  using Timer0/1/2/4 with INTERRUPT operation.
*
*  When source runs normally,
*    LED0 shows about 30.5 Hz waveform
*    LED1 shows 0.5 Hz waveform which is accurate (real-time timer)
*    LED2 shows 0.5 Hz waveform which has deviation
*    LED3 shows 0.5 Hz waveform which has deviation
*
********************************************************************/


/********************************************************************
*	Header Files
********************************************************************/

#include <xc.h>			// Mandatory header file
#include "pic16f1937.h"	// This contains various register definition of PIC16F1937 

#include "drv_osc.h"
#include "drv_pio.h"
#include "drv_wdt.h"
#include "drv_timer.h"


/********************************************************************
*	Macro Definition
********************************************************************/

/* To use __delay_us() or __delay_ms(), _XTAL_FREQ has to be set. */
/* The value of _XTAL_FREQ is clock value which is set by user.   */
#define _XTAL_FREQ 16000000


/********************************************************************
*	Global/Static Function
********************************************************************/


/********************************************************************
* Function		: main
* Description	: Main application to test PIOB
* Argument		: None
* Return		: None
********************************************************************/

void main(void)
{
	/* CONFIG1 and CONFIG2 is in the ConfigBits.c */

	/* Disable watchdog timer. */
	DRV_WDT_Init(0, 0);

	/* Set system clock to 16MHz. */
	DRV_OSC_Init();

	/* Initialize PortB to output. */
	DRV_PIOB_Init();

	/*------------------------------------------------------------------*/
	/* Initialize Timer0 to make 30.5Hz waveform on the pin 0 in PortB. */
	/* How to make 30.5Hz :                                             */
	/* i) Set Timer0 clock to Internal instruction cycle clock (FOSC/4) */
	/* ii) Set prescale ratio to 1:256.                                 */
	/* When executed, number of ticks of Timer0 is                      */
	/*    (16000000 / 4) / 256 = about 61.035                           */
	/* 61-times tick mean 30.5 Hz.                                      */
	/*------------------------------------------------------------------*/
	DRV_Timer0_Init(1);

	/*------------------------------------------------------------------*/
	/* Initialize Timer1 to make 1 second tick.                         */
	/* How to make 1 second tick :                                      */
	/* i) Set Timer1 clock to external oscillator running 32.768KHz.    */
	/* ii) Set prescale ratio to 1:1.                                   */
	/* iii) Set timer register to 32768.                                */
	/*------------------------------------------------------------------*/
	DRV_Timer1_Init(1);

	/*------------------------------------------------------------------*/
	/* Initialize Timer2 to make 1second tick.                          */
	/* How to make 1 second tick :                                      */
	/* i) Set Timer0 clock to Internal instruction cycle clock (FOSC/4) */
	/* ii) Set prescale ratio to 1:256 ( = 1 : 16 * 16).                */
	/* iii) Set Period Register to 255.                                 */
	/* iv) Increment variable by 1 whenever tick happens.               */
	/* When the variable is 61, toggle RB2.                             */
	/*                                                                  */
	/* [CAUTION] SEE THIS!                                              */
	/* Compare the lightning period between RB2 and RB1.                */
	/* More time passes, more gap happens. This means 8bits timer is    */
	/* NOT proper to make real-time timer, but 16bits timer is proper.  */
	/*------------------------------------------------------------------*/
	DRV_Timer2_Init(1);
	
	/*------------------------------------------------------------------*/
	/* Initialize Timer4 to make 1second tick.                          */
	/* How to make 1 second tick :                                      */
	/* i) Set Timer0 clock to Internal instruction cycle clock (FOSC/4) */
	/* ii) Set prescale ratio to 1:1024 ( = 1 : 16 * 64).               */
	/* iii) Set Period Register to 1.                                   */
	/* iv) Increment variable by 1 whenever tick happens.               */
	/* When the variable is 1953, toggle RB3.                           */
	/*                                                                  */
	/* [CAUTION] SEE THIS!                                              */
	/* Compare the lightning period between RB3, RB2 and RB1 each other.*/
	/*------------------------------------------------------------------*/
	DRV_Timer4_Init(1);

	/*------------------------------------------------------------------*/
	/* To activate peripheral interrupt, GIE and PEIE must be set.      */
	/*------------------------------------------------------------------*/
	/* Set Global Interrupt Enable bit. */
	INTCONbits.GIE = 1;

	/* Set Peripheral Interrupt Enable bit. */
	INTCONbits.PEIE = 1;

	while(1);	// background operation is necessary when interrupt works.
}

/* End of File */
